| /freebsd/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_hip_runtime_wrapper.h | 62 __device__ unsigned long long __ockl_dm_alloc(unsigned long long __size); 65 __device__ unsigned long long __asan_malloc_impl(unsigned long long __size, 69 __attribute__((noinline, weak)) __device__ void *malloc(__hip_size_t __size) { in malloc() argument 71 return (void *)__asan_malloc_impl(__size, __pc); in malloc() 78 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) { in malloc() argument 79 return (void *) __ockl_dm_alloc(__size); in malloc() 87 __device__ void *__hip_malloc(__hip_size_t __size); 89 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) { 90 return __hip_malloc(__size); 96 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) {
|
| H A D | mm_malloc.h | 19 extern int posix_memalign(void **__memptr, size_t __alignment, size_t __size); 25 extern "C" int posix_memalign(void **__memptr, size_t __alignment, size_t __size); 33 _mm_malloc(size_t __size, size_t __align) { in _mm_malloc() argument 35 return malloc(__size); in _mm_malloc() 43 __mallocedMemory = __mingw_aligned_malloc(__size, __align); in _mm_malloc() 45 __mallocedMemory = _aligned_malloc(__size, __align); in _mm_malloc() 47 if (posix_memalign(&__mallocedMemory, __align, __size)) in _mm_malloc()
|
| /freebsd/contrib/llvm-project/libcxx/include/__memory/ |
| H A D | aligned_alloc.h | 29 …e _LIBCPP_HIDE_FROM_ABI void* __libcpp_aligned_alloc(std::size_t __alignment, std::size_t __size) { in __libcpp_aligned_alloc() argument 31 return ::_aligned_malloc(__size, __alignment); in __libcpp_aligned_alloc() 39 size_t __rounded_size = (__size + __alignment - 1) & ~(__alignment - 1); in __libcpp_aligned_alloc() 42 return ::aligned_alloc(__alignment, __size > __rounded_size ? __size : __rounded_size); in __libcpp_aligned_alloc() 45 (void)::posix_memalign(&__result, __alignment, __size); in __libcpp_aligned_alloc()
|
| /freebsd/contrib/llvm-project/libcxx/include/__new/ |
| H A D | allocate.h | 55 size_t __size = static_cast<size_t>(__n) * sizeof(_Tp); variable 59 return static_cast<_Tp*>(std::__libcpp_operator_new(__size, __align_val)); 64 return static_cast<_Tp*>(std::__libcpp_operator_new(__size)); 76 size_t __size = static_cast<size_t>(__n) * sizeof(_Tp); variable 77 (void)__size; 80 return std::__libcpp_operator_delete(__ptr _LIBCPP_ONLY_IF_SIZED_DEALLOCATION(, __size)); 84 …return std::__libcpp_operator_delete(__ptr _LIBCPP_ONLY_IF_SIZED_DEALLOCATION(, __size), __align_v… 86 return std::__libcpp_operator_delete(__ptr _LIBCPP_ONLY_IF_SIZED_DEALLOCATION(, __size));
|
| /freebsd/contrib/llvm-project/libcxx/include/__format/ |
| H A D | formatter_integral.h | 93 _LIBCPP_HIDE_FROM_ABI inline string __determine_grouping(ptrdiff_t __size, const string& __grouping… in __determine_grouping() argument 94 _LIBCPP_ASSERT_INTERNAL(!__grouping.empty() && __size > __grouping[0], in __determine_grouping() 101 __size -= *__ptr; in __determine_grouping() 102 if (__size > 0) in __determine_grouping() 106 __r.push_back(*__ptr + __size); in __determine_grouping() 223 int __size = (__first - __begin) + // [sign][prefix] in __write_using_decimal_separators() local 232 if (__specs.__width_ > __size) { in __write_using_decimal_separators() 234 __padding.__before_ = __specs.__width_ - __size; in __write_using_decimal_separators() 235 …__out_it = __formatter::__fill(std::move(__out_it), __specs.__width_ - __size, _CharT('… in __write_using_decimal_separators() 238 if (__specs.__width_ > __size) { in __write_using_decimal_separators() [all …]
|
| H A D | formatter_output.h | 54 __padding_size(size_t __size, size_t __width, __format_spec::__alignment __align) { in __padding_size() argument 55 _LIBCPP_ASSERT_INTERNAL(__width > __size, "don't call this function when no padding is required"); in __padding_size() 59 size_t __fill = __width - __size; in __padding_size() 220 ptrdiff_t __size) -> decltype(__out_it) { 221 if (__size >= __specs.__width_) 224 …__padding_size_result __padding = __formatter::__padding_size(__size, __specs.__width_, __specs.__… 236 ptrdiff_t __size) -> decltype(__out_it) { 238 …urn __formatter::__write(basic_string_view{__first, __last}, std::move(__out_it), __specs, __size); 266 ptrdiff_t __size = __last - __first; variable 267 if (__size >= __specs.__width_) [all …]
|
| H A D | formatter_floating_point.h | 226 ptrdiff_t __size = __last - __first; 227 if (__size >= 4) { 228 __first = __last - std::min(__size, ptrdiff_t(6)); 517 ptrdiff_t __size = 525 if (__size < __specs.__width_) { 531 __padding = __formatter::__padding_size(__size, __specs.__width_, __specs.__alignment_); 622 size_t __size, 629 …__formatter::__padding_size(__size + __num_trailing_zeros, __specs.__width_, __specs.__alignment_); 714 ptrdiff_t __size = __result.__last - __buffer.begin(); 716 if (__size + __num_trailing_zeros >= __specs.__width_) { [all …]
|
| H A D | format_functions.h | 121 const __arg_t* __args, const __compile_time_handle<_CharT>* __handles, size_t __size) in __compile_time_basic_format_context() 122 : __args_(__args), __handles_(__handles), __size_(__size) {} in __compile_time_basic_format_context() 414 …basic_format_parse_context{__fmt, __args.__size()}, std::__format_context_create(std::move(__out_i… in requires() 417 std::__format::__vformat_to(basic_format_parse_context{__fmt, __args.__size()}, in requires() 535 std::__format::__vformat_to(basic_format_parse_context{__fmt, __args.__size()}, in __vformat_to_n() 557 std::__format::__vformat_to(basic_format_parse_context{__fmt, __args.__size()}, in __vformatted_size() 586 return std::__format::__vformat_to(basic_format_parse_context{__fmt, __args.__size()}, in requires() 591 basic_format_parse_context{__fmt, __args.__size()}, in requires() 670 basic_format_parse_context{__fmt, __args.__size()}, in __vformat_to_n() 695 basic_format_parse_context{__fmt, __args.__size()}, in __vformatted_size()
|
| /freebsd/contrib/llvm-project/compiler-rt/lib/asan/ |
| H A D | asan_interceptors_memintrinsics.h | 58 uptr __size = (uptr)(size); \ in DECLARE_REAL() 60 if (UNLIKELY(__offset > __offset + __size)) { \ in DECLARE_REAL() 62 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL() 64 if (UNLIKELY(!QuickCheckForUnpoisonedRegion(__offset, __size)) && \ in DECLARE_REAL() 65 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL() 77 ReportGenericError(pc, bp, sp, __bad, isWrite, __size, 0, false); \ in DECLARE_REAL()
|
| /freebsd/contrib/llvm-project/libcxx/include/__pstl/internal/omp/ |
| H A D | parallel_stable_sort.h | |
| H A D | util.h | |
| H A D | parallel_for_each.h | |
| /freebsd/contrib/llvm-project/libcxx/include/__debug_utils/ |
| H A D | strict_weak_ordering_check.h | 38 __diff_t __size = __last - __first > __diff_t(100) ? __diff_t(100) : __last - __first; in __check_strict_weak_ordering_sorted() local 40 while (__p < __size) { in __check_strict_weak_ordering_sorted() 43 while (__q < __size && !__comp(*(__first + __p), *(__first + __q))) { in __check_strict_weak_ordering_sorted() 55 // Check that elements between __p and __q are less than between __q and __size. in __check_strict_weak_ordering_sorted() 57 for (__diff_t __b = __q; __b < __size; ++__b) { in __check_strict_weak_ordering_sorted()
|
| /freebsd/contrib/llvm-project/libcxx/include/__cxx03/__debug_utils/ |
| H A D | strict_weak_ordering_check.h | 38 __diff_t __size = __last - __first > __diff_t(100) ? __diff_t(100) : __last - __first; in __check_strict_weak_ordering_sorted() local 40 while (__p < __size) { in __check_strict_weak_ordering_sorted() 43 while (__q < __size && !__comp(*(__first + __p), *(__first + __q))) { in __check_strict_weak_ordering_sorted() 57 for (__diff_t __b = __q; __b < __size; ++__b) { in __check_strict_weak_ordering_sorted()
|
| /freebsd/contrib/llvm-project/libcxx/include/__cxx03/__memory/ |
| H A D | aligned_alloc.h | 30 …e _LIBCPP_HIDE_FROM_ABI void* __libcpp_aligned_alloc(std::size_t __alignment, std::size_t __size) { in __libcpp_aligned_alloc() argument 32 return ::_aligned_malloc(__size, __alignment); in __libcpp_aligned_alloc() 35 (void)::posix_memalign(&__result, __alignment, __size); in __libcpp_aligned_alloc()
|
| H A D | builtin_new_allocator.h | 31 _LIBCPP_HIDE_FROM_ABI explicit __builtin_new_deleter(size_t __size, size_t __align) in __builtin_new_deleter() 32 : __size_(__size), __align_(__align) {} in __builtin_new_deleter()
|
| /freebsd/contrib/llvm-project/libcxx/include/__pstl/backends/ |
| H A D | libdispatch.h | 73 …nst__]] _LIBCPP_EXPORTED_FROM_ABI __chunk_partitions __partition_chunks(ptrdiff_t __size) noexcept; 261 const auto __size = __last - __first; 262 auto __partitions = __libdispatch::__partition_chunks(__size); 274 auto __destroy = [__size](_Value* __ptr) { 275 std::destroy_n(__ptr, __size); 276 std::allocator<_Value>().deallocate(__ptr, __size); 280 …unique_ptr<_Value[], decltype(__destroy)> __values(std::allocator<_Value>().allocate(__size), __de… 285 for (__iter_diff_t<_RandomAccessIterator> __i = 1; __i != __size; ++__i) { 288 *__first = std::move(__values.get()[__size - 1]); 342 std::move(__values.get(), __values.get() + __size, __first);
|
| /freebsd/sys/contrib/xen/io/ |
| H A D | ring.h | 178 #define FRONT_RING_ATTACH(_r, _s, _i, __size) do { \ argument 181 (_r)->nr_ents = __RING_SIZE(_s, __size); \ 185 #define FRONT_RING_INIT(_r, _s, __size) FRONT_RING_ATTACH(_r, _s, 0, __size) argument 187 #define BACK_RING_ATTACH(_r, _s, _i, __size) do { \ argument 190 (_r)->nr_ents = __RING_SIZE(_s, __size); \ 194 #define BACK_RING_INIT(_r, _s, __size) BACK_RING_ATTACH(_r, _s, 0, __size) argument
|
| /freebsd/contrib/llvm-project/libcxx/include/__cxx03/ |
| H A D | new | 262 inline _LIBCPP_HIDE_FROM_ABI void* __libcpp_allocate(size_t __size, size_t __align) { 266 return __libcpp_operator_new(__size, __align_val); 271 return __libcpp_operator_new(__size); 275 _LIBCPP_HIDE_FROM_ABI void __do_deallocate_handle_size(void* __ptr, size_t __size, _Args... __args)… 277 (void)__size; 280 return std::__libcpp_operator_delete(__ptr, __size, __args...); 284 inline _LIBCPP_HIDE_FROM_ABI void __libcpp_deallocate(void* __ptr, size_t __size, size_t __align) { 287 return __do_deallocate_handle_size(__ptr, __size); 291 return __do_deallocate_handle_size(__ptr, __size, __align_val); 293 return __do_deallocate_handle_size(__ptr, __size);
|
| /freebsd/contrib/llvm-project/clang/lib/Headers/ppc_wrappers/ |
| H A D | mm_malloc.h | 26 static __inline void *_mm_malloc(size_t __size, size_t __alignment) { in _mm_malloc() argument 33 if (posix_memalign(&__ptr, __alignment, __size) == 0) in _mm_malloc()
|
| /freebsd/contrib/llvm-project/libcxx/include/__algorithm/ |
| H A D | ranges_search_n.h | 50 auto __size = ranges::distance(__first, __last); in __ranges_search_n_impl() local 51 if (__size < __count) { in __ranges_search_n_impl() 58 __first, __last, __count, __value, __pred, __proj, __size); in __ranges_search_n_impl()
|
| /freebsd/usr.sbin/bsdconfig/share/ |
| H A D | strings.subr | 104 local __tmp="$1" __start="${2:-1}" __size="$3" 112 if ! [ "${__size:-1}" -ge 1 ] 2> /dev/null; then 136 __trim=$(( $__tmp_size - ${__size:-$__tmp_size} )) 140 if [ $__trim -le $__size ]; then 156 $__size / $__tbuf_len 161 __trimq=$(( $__size / $__tbuf_len )) 162 if [ $__size -ne $(( 172 $__tmp_size - $__mask_len - $__size 232 local __var_to_set="$1" __size="$2" 237 f_substr "$__var_to_set" "$__f_snprintf_tmp" 1 "$__size"
|
| /freebsd/contrib/llvm-project/libcxx/include/__utility/ |
| H A D | is_pointer_in_range.h | 63 auto __size = __end - __begin; 64 auto __end2 = __begin2 + __size;
|
| /freebsd/contrib/llvm-project/libcxx/include/ |
| H A D | deque | 595 _LIBCPP_HIDE_FROM_ABI ~_ConstructTransaction() { __base_->__size() += (__pos_ - __begin_); } 756 _LIBCPP_HIDE_FROM_ABI size_type size() const _NOEXCEPT { return __size(); } 758 _LIBCPP_HIDE_FROM_ABI size_type& __size() _NOEXCEPT { return __size_; } 759 _LIBCPP_HIDE_FROM_ABI const size_type& __size() const _NOEXCEPT { return __size_; } 898 __size() = __c.size(); 900 __c.__start_ = __c.__size() = 0; 1365 __c.__size() = 0; 1376 __c.__size() = 0; 1380 __size() = 0; 1585 ++__size(); [all …]
|
| /freebsd/contrib/llvm-project/libcxx/include/__mdspan/ |
| H A D | layout_left.h | 140 index_type __size = 1; in required_span_size() local 142 __size *= __extents_.extent(__r); in required_span_size() 143 return __size; in required_span_size()
|